﻿using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Linq;

namespace PanelBarSample
{
    public class MainViewModel
    {
        #region INotifyPropertyChanged values

        public event PropertyChangedEventHandler PropertyChanged;

        protected void RaisePropertyChanged(string propertyName)
        {
            var handler = PropertyChanged;
            if (handler != null)
            {
                handler(this, new PropertyChangedEventArgs(propertyName));
            }
        }
        #endregion

        public MainViewModel()
        {
            this.PanelBarZoneContainers = new ObservableCollection<PanelBarZoneContainerViewModel>();
        }

        private PanelBarZoneContainerViewModel currentPanelBarContainer;
        public PanelBarZoneContainerViewModel CurrentPanelBarContainer
        {
            get
            {
                return this.currentPanelBarContainer;
            }

            set
            {
                if (this.currentPanelBarContainer != value)
                {
                    this.currentPanelBarContainer = value;

                    // set the IsSelected for the current and all others to false 
                    this.PanelBarZoneContainers.Where(pb => pb.IsSelected == false).ToList().ForEach((pb) =>
                    {
                        pb.ZoneExtender.IsSelected = false;
                        pb.IsSelected = false;
                    });

                    this.currentPanelBarContainer.ZoneExtender.IsSelected = true;
                    this.currentPanelBarContainer.IsSelected = true;
                    this.RaisePropertyChanged("CurrentPanelBarContainer");
                }
            }
        }

        public ObservableCollection<PanelBarZoneContainerViewModel> PanelBarZoneContainers
        {
            get;
            set;
        }

    }
}
